aboutsummaryrefslogtreecommitdiffstats
path: root/epan/packet_info.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2010-12-20 05:35:29 +0000
committerGuy Harris <guy@alum.mit.edu>2010-12-20 05:35:29 +0000
commita8bc4a0d136d7a68e8f006aec75a8e63191948c9 (patch)
tree2587cbb5c31f65afc60711d38d5dcc79a5a689e6 /epan/packet_info.h
parent7e16ec5b991b12020f7bdc135fd4943858bc3218 (diff)
Rename the routines that handle dissector tables with unsigned integer
keys to have _uint in their names, to match the routines that handle dissector tables with string keys. (Using _port can confuse people into thinking they're intended solely for use with TCP/UDP/etc. ports when, in fact, they work better for things such as Ethernet types, where the binding of particular values to particular protocols are a lot stronger.) svn path=/trunk/; revision=35224
Diffstat (limited to 'epan/packet_info.h')
-rw-r--r--epan/packet_info.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/epan/packet_info.h b/epan/packet_info.h
index 8446685c49..646a24a7be 100644
--- a/epan/packet_info.h
+++ b/epan/packet_info.h
@@ -69,7 +69,7 @@ typedef struct _packet_info {
port_type ptype; /* type of the following two port numbers */
guint32 srcport; /* source port */
guint32 destport; /* destination port */
- guint32 match_port; /* matched port for calling subdissector from table */
+ guint32 match_uint; /* matched uint for calling subdissector from table */
const char *match_string; /* matched string for calling subdissector from table */
guint16 can_desegment; /* >0 if this segment could be desegmented.
A dissector that can offer this API (e.g.
@@ -201,4 +201,7 @@ typedef struct _packet_info {
*/
} packet_info;
+/* For old code that hasn't yet been changed. */
+#define match_port match_uint
+
#endif /* __PACKET_INFO_H__ */